<?php
/**
 * Plugin Name: Easy ChatGPT powered article generator
 * Plugin URI:  https://wpblog.ir/
 * Description: The first <strong>plugin </strong> is free and does not require an API key through <a href="https://wpblog.ir">wpblog</a>
 * Version:     1.0.0
 * Author:      chapioon
 * Author URI:  https://chapioon.com/
 * License:     GPLv2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: wpblog-ai-content-creator
 * Domain Path: /languages
 *
 * @package wpblog-ai-content-creator
 */

defined( 'ABSPATH' ) || die( esc_html( __( 'Access is not allowed.', 'wpblog-ai-content-creator' ) ) );

/** Missing load_plugin_textdomain(). en el canal de Slack #meta-language-packs. */
function aicc_load_plugin_textdomain() {
	load_plugin_textdomain( 'wpblog-ai-content-creator', false, basename( dirname( __FILE__ ) ) . '/languages' );
}
add_action( 'plugins_loaded', 'aicc_load_plugin_textdomain' );

/** managing debug. */
function aicc_modo_debug() {
	return false;
}

// if admin incload plugin.
if ( is_admin() ) {
	require_once plugin_dir_path( __FILE__ ) . 'admin/configuracion.php';
	require_once plugin_dir_path( __FILE__ ) . 'admin/opciones.php';
	require_once plugin_dir_path( __FILE__ ) . 'bbdd.php';
	require_once plugin_dir_path( __FILE__ ) . 'classes/class-aiccgeneracion.php';
	require_once plugin_dir_path( __FILE__ ) . 'admin/posproduccion.php';
	require_once plugin_dir_path( __FILE__ ) . 'admin/pixabay.php';
	require_once plugin_dir_path( __FILE__ ) . 'admin/funciones.php';
	require_once plugin_dir_path( __FILE__ ) . 'admin/idiomas.php';
	require_once plugin_dir_path( __FILE__ ) . 'admin/ayuda.php';
	add_action( 'wp_enqueue_scripts', 'aicc_load_wp_icons' );
	add_action( 'admin_enqueue_scripts', 'aicc_enqueue_admin_styles' );
	aicc_actualizar_db_si_procede();
}

/** link to setting:
 * https://www.smashingmagazine.com/2011/03/ten-things-every-wordpress-plugin-developer-should-know/
 *
 * @param array  $links An array of plugin action links.
 * @param string $file Path to the plugin file relative to the plugins directory.
 * @return HTML con el enlace HTML a los ajustes.
 */
function aicc_plugin_action_links( $links, $file ) {
	static $this_plugin;
	if ( ! $this_plugin ) {
		$this_plugin = plugin_basename( __FILE__ );
	}
	if ( $file === $this_plugin ) {
		// The value of the page parameter is the slug of the options page.
		$settings_link = '<a href="' . esc_url( admin_url( 'admin.php?page=aicc_settings' ) ) . '" title="' . ucfirst( __( 'plugin settings', 'wpblog-ai-content-creator' ) ) . '">' . __( 'Settings', 'wpblog-ai-content-creator' ) . '</a>';
		array_unshift( $links, $settings_link );
	}
	return $links;
}
add_filter( 'plugin_action_links', 'aicc_plugin_action_links', 10, 2 );


/** active plugin by hook. */
function aicc_activacion() {
	require_once plugin_dir_path( __FILE__ ) . 'lista-opciones.php';
	require_once plugin_dir_path( __FILE__ ) . 'bbdd.php';
	aicc_crear_tabla_generaciones();
	aicc_crear_tabla_pixabay_cache();
}
register_activation_hook( __FILE__, 'aicc_activacion' );

/** chack update data base. */
function aicc_actualizar_db_si_procede() {

	if ( ! function_exists( 'is_plugin_active' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}
	if ( is_plugin_active( plugin_basename( __FILE__ ) ) ) {
		if ( aicc_requiere_actualizar_tabla_generaciones() ) {
			aicc_actualizar_tabla_generaciones();
		}
		if ( aicc_requiere_actualizar_tabla_pixabay_cache() ) {
			aicc_actualizar_tabla_pixabay_cache();
		}
	}
}

/** Incorporates the style for dashicons. */
function aicc_load_wp_icons() {
	wp_enqueue_style( 'dashicons' );
}

/** Incorporates the style to display Pixabay thumbnails.
 *
 * @param string $hook_suffix Slug of the page where to apply it.
 */
function aicc_enqueue_admin_styles( $hook_suffix ) {
	// // Replace 'my-plugin-page' with the plugin page slug in the admin panel
	// if ( 'mi-plugin-page' === $hook_suffix ) {
		wp_enqueue_style(
			'aicc-pixabay',
			plugin_dir_url( __FILE__ ) . 'admin/css/pixabay.css',
			array(),
			'1.0.0'
		);
	// }
}

/** Returns the plugin version. */
function aicc_get_version() {
	if ( ! function_exists( 'get_plugin_data' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}
	$plugin_data    = get_plugin_data( __FILE__ );
	$plugin_version = $plugin_data['Version'];
	return $plugin_version;
}
